#ifndef HELP_H
#define HELP_H

#include <QMainWindow>
#include <QtNetwork>
#include <QSettings>

namespace Ui {
    class Help;
}

class Help : public QMainWindow {
    Q_OBJECT
public:
    Help(QWidget *parent = 0);
    ~Help();

protected:
    void changeEvent(QEvent *e);

private:
    Ui::Help *ui;
    QSettings mvSettings;
};

#endif // HELP_H
